@@ -8,7 +8,7 @@ from .src.utils.CreatBannerOne import generationOne, signature, openUserImg
 from .src.utils.userProfile import creatUserProfile
 from .src.utils.translation import translationLang,supportLang
 from .enc_error import ENCardError
-import time
+
 
 logging.getLogger('enkanetwork.assets').setLevel(logging.CRITICAL)
 
@@ -39,13 +39,12 @@ def saveBanner(uid,res,name):
     res.save(f"{path}/EnkaImg/{uid}/{name}_{data}.png")
 
 def generation(charter,assets,img,adapt,uid,RESULT, save,signatureRes,translateLang,splash,teample = 1):
-    a = time.time()
     if teample == 1:
         result = generationOne(charter,assets,img,adapt,signatureRes,translateLang["lvl"],splash)
     else:
         result = generationTwo(charter,assets,img,adapt,signatureRes,translateLang,splash)
     if not save:
-        saveBanner(uid,result,charter.name)
+        Thread(target=saveBanner, args=(uid,result,charter.name)).start()
     else:
         if not uid in RESULT:
             RESULT[uid] = {}
