@@ -4,7 +4,7 @@ from PIL import Image, ImageChops
 from .openFile import *
 from .options import *
 from .gradient import userAdaptGrandient
-import time
+from cachetools import cached, TTLCache
 
 
 def centryImage(userImages, teample = 1):
@@ -36,6 +36,7 @@ def centryImage(userImages, teample = 1):
             return userImages, 0
         else:
             return userImages, 555
+
 def openImageElement(element,teample = 1):
     if teample == 1:
         if element == "Fire":
@@ -71,6 +72,7 @@ def openImageElement(element,teample = 1):
             return CryoBgTeampleTwo.copy()
         else:
             return ErrorBgTeampleTwo.copy()
+
 def openImageElementConstant(element):
     if element == "Fire":
         return PyroConstant.copy()
@@ -105,6 +107,7 @@ def maskaAdd(element,charter, teample = 1):
         bg.paste(MasskaEffectDown,(0,0),MasskaEffectDown)
     return bg
 
+@cached(cache=TTLCache(maxsize=1024, ttl=600))
 def userImage(img,element = None, adaptation = False):
     userImagess,pozitionX = centryImage(img)
     if adaptation:
@@ -117,7 +120,6 @@ def userImage(img,element = None, adaptation = False):
     else:
         try:
             bg = openImageElement(element)
-            #bg.load()
             effect = bg.copy()
         except Exception as e:
             print(e)
@@ -127,6 +129,7 @@ def userImage(img,element = None, adaptation = False):
         bg.paste(im,(0,0))
         return bg
 
+@cached(cache=TTLCache(maxsize=1024, ttl=600))
 def userImageTwo(img,element = None, adaptation = False):
     userImagess,pozitionX = centryImage(img, teample = 2)
     if adaptation:
@@ -167,7 +170,7 @@ def userImageBlur(img,element = None, adaptation = False):
         img.paste(im,(0,0))
         return img
 '''
-
+@cached(cache=TTLCache(maxsize=1024, ttl=600))
 def star(x):
     if x == 1:
         imgs = Star1
@@ -180,9 +183,9 @@ def star(x):
     elif x == 5:
         imgs = Star5
 
-    return imgs
-
+    return imgs.copy()
 
+@cached(cache=TTLCache(maxsize=1024, ttl=600))
 def elementIconPanel(element):
     if element == "Fire":
         return PyroCharterElementTeampleTwo.copy()
@@ -201,6 +204,7 @@ def elementIconPanel(element):
     else:
         return PyroCharterElementTeampleTwo.copy()
 
+@cached(cache=TTLCache(maxsize=1024, ttl=600))
 def getIconAdd(x, icon = False, size = None):
     if not icon:
         if not x in IconAddTrue:
@@ -247,6 +251,6 @@ def getIconAdd(x, icon = False, size = None):
         return False
     if size:
         icons.thumbnail(size)
-        return icons.convert("RGBA")
+        return icons.convert("RGBA").copy()
     else:
-        return icons.convert("RGBA")
+        return icons.convert("RGBA").copy()
